## $Id: applicant.py 16273 2020-10-09 07:07:15Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.interface import implementedBy
from zope.component import getUtility
from waeup.kofa.interfaces import IExtFileStore
from waeup.kofa.applicants.applicant import ApplicantFactory
from waeup.kofa.applicants.refereereport import (
    ApplicantRefereeReport, ApplicantRefereeReportFactory)
from waeup.kofa.utils.helpers import attrs_to_fields
from kofacustom.nigeria.applicants.applicant import NigeriaApplicant
from kofacustom.iuokada.applicants.interfaces import(
    ICustomApplicant, ICustomUGApplicantEdit, ICustomPGApplicantEdit,
    IPUTMEApplicantEdit, ICustomApplicantRefereeReport, ITranscriptApplicant)

class CustomApplicant(NigeriaApplicant):

    grok.implements(ICustomApplicant, ICustomUGApplicantEdit,
        ICustomPGApplicantEdit, IPUTMEApplicantEdit, ITranscriptApplicant)
    grok.provides(ICustomApplicant)

    applicant_student_mapping = NigeriaApplicant.applicant_student_mapping + [
        ('lga', 'lga'),
        ('nationality', 'nationality'),
        ('fst_sit_fname', 'fst_sit_fname'),
        ('fst_sit_no', 'fst_sit_no'),
        ('fst_sit_date', 'fst_sit_date'),
        ('fst_sit_type', 'fst_sit_type'),
        ('fst_sit_results', 'fst_sit_results'),
        ('scd_sit_fname', 'scd_sit_fname'),
        ('scd_sit_no', 'scd_sit_no'),
        ('scd_sit_date', 'scd_sit_date'),
        ('scd_sit_type', 'scd_sit_type'),
        ('scd_sit_results', 'scd_sit_results'),
        ('hq_type', 'hq_type'),
        ('hq_fname', 'hq_fname'),
        ('hq_matric_no', 'hq_matric_no'),
        ('hq_degree', 'hq_degree'),
        ('hq_school', 'hq_school'),
        ('hq_session', 'hq_session'),
        ('hq_disc', 'hq_disc'),
        # added
        ('sponsor', 'sponsor'),
        ]

CustomApplicant = attrs_to_fields(CustomApplicant)

class CustomApplicantFactory(ApplicantFactory):
    """A factory for customized applicants.
    """

    def __call__(self, *args, **kw):
        return CustomApplicant()

    def getInterfaces(self):
        return implementedBy(CustomApplicant)

class CustomApplicantRefereeReport(ApplicantRefereeReport):
    """This is a custom referee report.
    """
    grok.implements(ICustomApplicantRefereeReport)
    grok.provides(ICustomApplicantRefereeReport)

CustomApplicantRefereeReport = attrs_to_fields(CustomApplicantRefereeReport)

class CustomApplicantRefereeReportFactory(ApplicantRefereeReportFactory):
    """A factory for applicant online payments.
    """

    def __call__(self, *args, **kw):
        return CustomApplicantRefereeReport()

    def getInterfaces(self):
        return implementedBy(CustomApplicantRefereeReport)

